#!/usr/bin/env python

from wfuzz.wfuzz import main

if __name__ == "__main__":
    main()
